@@ -58,6 +58,8 @@ static void at_cbm_notify(GAtResult *result, gpointer user_data)
 	unsigned char pdu[88];
 	long hexpdulen;
 
+	DBG("");
+
 	g_at_result_iter_init(&iter, result);
 
 	if (!g_at_result_iter_next(&iter, "+CBM:"))
@@ -72,8 +74,7 @@ static void at_cbm_notify(GAtResult *result, gpointer user_data)
 	}
 
 	hexpdu = g_at_result_pdu(result);
-
-	if (!hexpdu) {
+	if (hexpdu == NULL) {
 		ofono_error("Got a CBM, but no PDU.  Are we in text mode?");
 		return;
 	}
@@ -112,7 +113,9 @@ static void at_cbs_set_topics(struct ofono_cbs *cbs, const char *topics,
 	char *buf;
 	unsigned int id;
 
-	if (!cbd)
+	DBG("");
+
+	if (cbd == NULL)
 		goto error;
 
 	/* For the Qualcomm based devices it is required to clear
@@ -137,8 +140,7 @@ static void at_cbs_set_topics(struct ofono_cbs *cbs, const char *topics,
 		return;
 
 error:
-	if (cbd)
-		g_free(cbd);
+	g_free(cbd);
 
 	CALLBACK_WITH_FAILURE(cb, user_data);
 }
@@ -150,7 +152,9 @@ static void at_cbs_clear_topics(struct ofono_cbs *cbs,
 	struct cb_data *cbd = cb_data_new(cb, user_data);
 	char buf[256];
 
-	if (!cbd)
+	DBG("");
+
+	if (cbd == NULL)
 		goto error;
 
 	if (data->cscb_mode_1)
@@ -163,8 +167,7 @@ static void at_cbs_clear_topics(struct ofono_cbs *cbs,
 		return;
 
 error:
-	if (cbd)
-		g_free(cbd);
+	g_free(cbd);
 
 	CALLBACK_WITH_FAILURE(cb, user_data);
 }
@@ -237,12 +240,12 @@ static int at_cbs_probe(struct ofono_cbs *cbs, unsigned int vendor,
 	struct cbs_data *data;
 
 	data = g_new0(struct cbs_data, 1);
-	data->chat = chat;
+	data->chat = g_at_chat_clone(chat);
 	data->vendor = vendor;
 
 	ofono_cbs_set_data(cbs, data);
 
-	g_at_chat_send(chat, "AT+CSCB=?", cscb_prefix,
+	g_at_chat_send(data->chat, "AT+CSCB=?", cscb_prefix,
 			at_cscb_support_cb, cbs, NULL);
 
 	return 0;
@@ -254,6 +257,7 @@ static void at_cbs_remove(struct ofono_cbs *cbs)
 
 	ofono_cbs_set_data(cbs, NULL);
 
+	g_at_chat_unref(data->chat);
 	g_free(data);
 }
 
@@ -265,12 +269,12 @@ static struct ofono_cbs_driver driver = {
 	.clear_topics = at_cbs_clear_topics,
 };
 
-void at_cbs_init()
+void at_cbs_init(void)
 {
 	ofono_cbs_driver_register(&driver);
 }
 
-void at_cbs_exit()
+void at_cbs_exit(void)
 {
 	ofono_cbs_driver_unregister(&driver);
 }
