@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2009  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -80,7 +80,7 @@ static GSList *find_dialing(GSList *calls)
 	c = g_slist_find_custom(calls, GINT_TO_POINTER(CALL_STATUS_DIALING),
 				at_util_call_compare_by_status);
 
-	if (!c)
+	if (c == NULL)
 		c = g_slist_find_custom(calls,
 					GINT_TO_POINTER(CALL_STATUS_ALERTING),
 					at_util_call_compare_by_status);
@@ -97,8 +97,7 @@ static struct ofono_call *create_call(struct ofono_voicecall *vc, int type,
 
 	/* Generate a call structure for the waiting call */
 	call = g_try_new0(struct ofono_call, 1);
-
-	if (!call)
+	if (call == NULL)
 		return NULL;
 
 	call->id = ofono_voicecall_get_next_callid(vc);
@@ -207,8 +206,6 @@ static void clcc_poll_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	unsigned int num_active = 0;
 	unsigned int num_held = 0;
 
-	dump_response("clcc_poll_cb", ok, result);
-
 	if (!ok)
 		return;
 
@@ -227,7 +224,7 @@ static void clcc_poll_cb(gboolean ok, GAtResult *result, gpointer user_data)
 		if (nc && (nc->status == CALL_STATUS_HELD))
 			num_held++;
 
-		if (oc && (!nc || (nc->id > oc->id))) {
+		if (oc && (nc == NULL || (nc->id > oc->id))) {
 			enum ofono_disconnect_reason reason;
 
 			if (vd->local_release & (0x1 << oc->id))
@@ -242,7 +239,7 @@ static void clcc_poll_cb(gboolean ok, GAtResult *result, gpointer user_data)
 			vd->local_release &= ~(1 << oc->id);
 
 			o = o->next;
-		} else if (nc && (!oc || (nc->id < oc->id))) {
+		} else if (nc && (oc == NULL || (nc->id < oc->id))) {
 			/* new call, signal it */
 			if (nc->type == 0)
 				ofono_voicecall_notify(vc, nc);
@@ -300,7 +297,6 @@ static void generic_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	struct voicecall_data *vd = ofono_voicecall_get_data(req->vc);
 	struct ofono_error error;
 
-	dump_response("generic_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (ok && req->affected_types) {
@@ -330,8 +326,6 @@ static void atd_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	struct ofono_call *call;
 	GSList *l;
 
-	dump_response("atd_cb", ok, result);
-
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (!ok)
@@ -349,8 +343,7 @@ static void atd_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	}
 
 	call = create_call(vc, 0, 0, CALL_STATUS_DIALING, NULL, type, validity);
-
-	if (!call) {
+	if (call == NULL) {
 		ofono_error("Unable to allocate call, "
 				"call tracking will fail!");
 		return;
@@ -369,18 +362,14 @@ static void hfp_dial(struct ofono_voicecall *vc,
 	struct cb_data *cbd = cb_data_new(cb, data);
 	char buf[256];
 
-	if (!cbd)
+	if (cbd == NULL)
 		goto error;
 
 	cbd->user = vc;
 	if (ph->type == 145)
-		sprintf(buf, "ATD+%s", ph->number);
+		snprintf(buf, sizeof(buf), "ATD+%s", ph->number);
 	else
-		sprintf(buf, "ATD%s", ph->number);
-
-	if ((clir != OFONO_CLIR_OPTION_DEFAULT) ||
-			(cug != OFONO_CUG_OPTION_DEFAULT))
-		goto error;
+		snprintf(buf, sizeof(buf), "ATD%s", ph->number);
 
 	strcat(buf, ";");
 
@@ -389,8 +378,7 @@ static void hfp_dial(struct ofono_voicecall *vc,
 		return;
 
 error:
-	if (cbd)
-		g_free(cbd);
+	g_free(cbd);
 
 	CALLBACK_WITH_FAILURE(cb, data);
 }
@@ -402,7 +390,7 @@ static void hfp_template(const char *cmd, struct ofono_voicecall *vc,
 	struct voicecall_data *vd = ofono_voicecall_get_data(vc);
 	struct change_state_req *req = g_try_new0(struct change_state_req, 1);
 
-	if (!req)
+	if (req == NULL)
 		goto error;
 
 	req->vc = vc;
@@ -415,8 +403,7 @@ static void hfp_template(const char *cmd, struct ofono_voicecall *vc,
 		return;
 
 error:
-	if (req)
-		g_free(req);
+	g_free(req);
 
 	CALLBACK_WITH_FAILURE(cb, data);
 }
@@ -497,7 +484,6 @@ static void release_id_cb(gboolean ok, GAtResult *result,
 	struct voicecall_data *vd = ofono_voicecall_get_data(req->vc);
 	struct ofono_error error;
 
-	dump_response("release_id_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (ok)
@@ -518,7 +504,7 @@ static void hfp_release_specific(struct ofono_voicecall *vc, int id,
 
 	req = g_try_new0(struct release_id_req, 1);
 
-	if (!req)
+	if (req == NULL)
 		goto error;
 
 	req->vc = vc;
@@ -526,15 +512,14 @@ static void hfp_release_specific(struct ofono_voicecall *vc, int id,
 	req->data = data;
 	req->id = id;
 
-	sprintf(buf, "AT+CHLD=1%d", id);
+	snprintf(buf, sizeof(buf), "AT+CHLD=1%d", id);
 
 	if (g_at_chat_send(vd->chat, buf, none_prefix,
 				release_id_cb, req, g_free) > 0)
 		return;
 
 error:
-	if (req)
-		g_free(req);
+	g_free(req);
 
 	CALLBACK_WITH_FAILURE(cb, data);
 }
@@ -546,7 +531,7 @@ static void hfp_private_chat(struct ofono_voicecall *vc, int id,
 	char buf[32];
 
 	if (vd->ag_mpty_features & AG_CHLD_2x) {
-		sprintf(buf, "AT+CHLD=2%d", id);
+		snprintf(buf, sizeof(buf), "AT+CHLD=2%d", id);
 
 		hfp_template(buf, vc, generic_cb, 0, cb, data);
 
@@ -575,7 +560,7 @@ static void hfp_transfer(struct ofono_voicecall *vc,
 {
 	struct voicecall_data *vd = ofono_voicecall_get_data(vc);
 	/* Transfer can puts held & active calls together and disconnects
-	 * from both.  However, some networks support transfering of
+	 * from both.  However, some networks support transferring of
 	 * dialing/ringing calls as well.
 	 */
 	unsigned int transfer = 0x1 | 0x2 | 0x4 | 0x8;
@@ -597,7 +582,7 @@ static void hfp_send_dtmf(struct ofono_voicecall *vc, const char *dtmf,
 	char *buf;
 	int s;
 
-	if (!req)
+	if (req == NULL)
 		goto error;
 
 	req->vc = vc;
@@ -605,10 +590,9 @@ static void hfp_send_dtmf(struct ofono_voicecall *vc, const char *dtmf,
 	req->data = data;
 	req->affected_types = 0;
 
-	/* strlen("AT+VTS=") = 7 */
-	buf = g_try_new(char, strlen(dtmf) + 7);
-
-	if (!buf)
+	/* strlen("AT+VTS=) = 7 + NULL */
+	buf = g_try_new(char, strlen(dtmf) + 8);
+	if (buf == NULL)
 		goto error;
 
 	sprintf(buf, "AT+VTS=%s", dtmf);
@@ -622,8 +606,7 @@ static void hfp_send_dtmf(struct ofono_voicecall *vc, const char *dtmf,
 		return;
 
 error:
-	if (req)
-		g_free(req);
+	g_free(req);
 
 	CALLBACK_WITH_FAILURE(cb, data);
 }
@@ -642,8 +625,6 @@ static void ccwa_notify(GAtResult *result, gpointer user_data)
 	int num_type, validity;
 	struct ofono_call *call;
 
-	dump_response("ccwa_notify", TRUE, result);
-
 	/* CCWA can repeat, ignore if we already have an waiting call */
 	if (g_slist_find_custom(vd->calls,
 				GINT_TO_POINTER(CALL_STATUS_WAITING),
@@ -666,11 +647,11 @@ static void ccwa_notify(GAtResult *result, gpointer user_data)
 	else
 		validity = 2;
 
-	ofono_debug("ccwa_notify: %s %d %d", num, num_type, validity);
+	DBG("ccwa_notify: %s %d %d", num, num_type, validity);
 
 	call = create_call(vc, 0, 1, 5, num, num_type, validity);
 
-	if (!call) {
+	if (call == NULL) {
 		ofono_error("malloc call struct failed.  "
 				"Call management is fubar");
 		return;
@@ -709,8 +690,6 @@ static void ring_notify(GAtResult *result, gpointer user_data)
 	struct ofono_call *call;
 	GSList *waiting;
 
-	dump_response("ring_notify", TRUE, result);
-
 	/* RING can repeat, ignore if we already have an incoming call */
 	if (g_slist_find_custom(vd->calls,
 				GINT_TO_POINTER(CALL_STATUS_INCOMING),
@@ -743,7 +722,7 @@ static void ring_notify(GAtResult *result, gpointer user_data)
 	/* Generate an incoming call of voice type */
 	call = create_call(vc, 0, 1, CALL_STATUS_INCOMING, NULL, 128, 2);
 
-	if (!call)
+	if (call == NULL)
 		ofono_error("Couldn't create call, call management is fubar!");
 
 	/* We don't know the number must wait for CLIP to arrive before
@@ -762,8 +741,6 @@ static void clip_notify(GAtResult *result, gpointer user_data)
 	GSList *l;
 	struct ofono_call *call;
 
-	dump_response("clip_notify", TRUE, result);
-
 	l = g_slist_find_custom(vd->calls,
 				GINT_TO_POINTER(CALL_STATUS_INCOMING),
 				at_util_call_compare_by_status);
@@ -795,7 +772,7 @@ static void clip_notify(GAtResult *result, gpointer user_data)
 	g_at_result_iter_skip_next(&iter);
 	g_at_result_iter_skip_next(&iter);
 
-	ofono_debug("clip_notify: %s %d %d", num, type, validity);
+	DBG("clip_notify: %s %d %d", num, type, validity);
 
 	call = l->data;
 
@@ -880,7 +857,6 @@ static void sync_dialing_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	struct ofono_call *oc;
 	struct ofono_call *nc;
 
-	dump_response("sync_dialing_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (!ok)
@@ -899,11 +875,11 @@ static void sync_dialing_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	 */
 	o = find_dialing(vd->calls);
 
-	if (!n && o) {
+	if (n == NULL && o) {
 		oc = o->data;
 		release_call(vc, oc);
 		vd->calls = g_slist_remove(vd->calls, oc);
-	} else if (n && !o) {
+	} else if (n && o == NULL) {
 		nc = n->data;
 		new_call_notify(vc, nc->type, nc->direction, nc->status,
 				nc->phone_number.number, nc->phone_number.type,
@@ -1120,7 +1096,7 @@ static void hfp_voicecall_initialized(gboolean ok, GAtResult *result,
 	struct ofono_voicecall *vc = user_data;
 	struct voicecall_data *vd = ofono_voicecall_get_data(vc);
 
-	ofono_debug("hfp_voicecall_init: registering to notifications");
+	DBG("hfp_voicecall_init: registering to notifications");
 
 	g_at_chat_register(vd->chat, "RING", ring_notify, FALSE, vc, NULL);
 	g_at_chat_register(vd->chat, "+CLIP:", clip_notify, FALSE, vc, NULL);
@@ -1183,7 +1159,7 @@ static struct ofono_voicecall_driver driver = {
 	.remove			= hfp_voicecall_remove,
 	.dial			= hfp_dial,
 	.answer			= hfp_answer,
-	.hangup			= hfp_hangup,
+	.hangup_active		= hfp_hangup,
 	.hold_all_active	= hfp_hold_all_active,
 	.release_all_held	= hfp_release_all_held,
 	.set_udub		= hfp_set_udub,
@@ -1197,12 +1173,12 @@ static struct ofono_voicecall_driver driver = {
 	.send_tones		= hfp_send_dtmf
 };
 
-void hfp_voicecall_init()
+void hfp_voicecall_init(void)
 {
 	ofono_voicecall_driver_register(&driver);
 }
 
-void hfp_voicecall_exit()
+void hfp_voicecall_exit(void)
 {
 	ofono_voicecall_driver_unregister(&driver);
 }
