@@ -57,22 +57,27 @@
 #include <ofono/radio-settings.h>
 #include <ofono/audio-settings.h>
 #include <ofono/stk.h>
+#include <ofono/ctm.h>
 #include <ofono/log.h>
 
 #include <drivers/atmodem/atutil.h>
 #include <drivers/atmodem/vendor.h>
 
-#define NUM_DLC  4
+#define NUM_DLC  6
 
 #define VOICE_DLC   0
 #define NETREG_DLC  1
-#define GPRS_DLC    2
-#define AUX_DLC     3
+#define GPRS1_DLC   2
+#define GPRS2_DLC   3
+#define GPRS3_DLC   4
+#define AUX_DLC     5
 
-static char *dlc_prefixes[NUM_DLC] = { "Voice: ", "Net: ", "GPRS: ", "Aux: " };
+static char *dlc_prefixes[NUM_DLC] = { "Voice: ", "Net: ", "GPRS1: ",
+					"GPRS2: ", "GPRS3: ", "Aux: " };
 
 static const char *dlc_nodes[NUM_DLC] = { "/dev/ttyGSM1", "/dev/ttyGSM2",
-					"/dev/ttyGSM7", "/dev/ttyGSM8" };
+					"/dev/ttyGSM3", "/dev/ttyGSM4",
+					"/dev/ttyGSM5", "/dev/ttyGSM6" };
 
 static const char *none_prefix[] = { NULL };
 static const char *xdrv_prefix[] = { "+XDRV:", NULL };
@@ -83,6 +88,8 @@ struct ifx_data {
 	GAtChat *dlcs[NUM_DLC];
 	guint dlc_poll_count;
 	guint dlc_poll_source;
+	guint dlc_init_source;
+	guint mux_init_timeout;
 	guint frame_size;
 	int mux_ldisc;
 	int saved_ldisc;
@@ -109,7 +116,7 @@ static int ifx_probe(struct ofono_modem *modem)
 	DBG("%p", modem);
 
 	data = g_try_new0(struct ifx_data, 1);
-	if (!data)
+	if (data == NULL)
 		return -ENOMEM;
 
 	data->mux_ldisc = -1;
@@ -139,7 +146,7 @@ static void xsim_notify(GAtResult *result, gpointer user_data)
 	GAtResultIter iter;
 	int state;
 
-	if (!data->sim)
+	if (data->sim == NULL)
 		return;
 
 	g_at_result_iter_init(&iter, result);
@@ -179,39 +186,19 @@ static void xsim_notify(GAtResult *result, gpointer user_data)
 	}
 }
 
-static GAtChat *create_chat(GIOChannel *channel, char *debug)
-{
-	GAtSyntax *syntax;
-	GAtChat *chat;
-
-	if (!channel)
-		return NULL;
-
-	syntax = g_at_syntax_new_gsmv1();
-	chat = g_at_chat_new(channel, syntax);
-	g_at_syntax_unref(syntax);
-	g_io_channel_unref(channel);
-
-	if (!chat)
-		return NULL;
-
-	if (getenv("OFONO_AT_DEBUG"))
-		g_at_chat_set_debug(chat, ifx_debug, debug);
-
-	g_at_chat_send(chat, "ATE0 +CMEE=1", NULL,
-					NULL, NULL, NULL);
-
-	return chat;
-}
-
 static void shutdown_device(struct ifx_data *data)
 {
 	int i, fd;
 
 	DBG("");
 
+	if (data->dlc_init_source > 0) {
+		g_source_remove(data->dlc_init_source);
+		data->dlc_init_source = 0;
+	}
+
 	for (i = 0; i < NUM_DLC; i++) {
-		if (!data->dlcs[i])
+		if (data->dlcs[i] == NULL)
 			continue;
 
 		g_at_chat_unref(data->dlcs[i]);
@@ -235,6 +222,43 @@ done:
 	data->device = NULL;
 }
 
+static void dlc_disconnect(gpointer user_data)
+{
+	struct ofono_modem *modem = user_data;
+	struct ifx_data *data = ofono_modem_get_data(modem);
+
+	DBG("");
+
+	ofono_warn("Disconnect of modem channel");
+
+	shutdown_device(data);
+}
+
+static GAtChat *create_chat(GIOChannel *channel, struct ofono_modem *modem,
+								char *debug)
+{
+	GAtSyntax *syntax;
+	GAtChat *chat;
+
+	if (channel == NULL)
+		return NULL;
+
+	syntax = g_at_syntax_new_gsmv1();
+	chat = g_at_chat_new(channel, syntax);
+	g_at_syntax_unref(syntax);
+	g_io_channel_unref(channel);
+
+	if (chat == NULL)
+		return NULL;
+
+	if (getenv("OFONO_AT_DEBUG"))
+		g_at_chat_set_debug(chat, ifx_debug, debug);
+
+	g_at_chat_set_disconnect_function(chat, dlc_disconnect, modem);
+
+	return chat;
+}
+
 static void xgendata_query(gboolean ok, GAtResult *result, gpointer user_data)
 {
 	struct ofono_modem *modem = user_data;
@@ -338,6 +362,30 @@ static void cfun_enable(gboolean ok, GAtResult *result, gpointer user_data)
 					xgendata_query, modem, NULL);
 }
 
+static gboolean dlc_setup(gpointer user_data)
+{
+	struct ofono_modem *modem = user_data;
+	struct ifx_data *data = ofono_modem_get_data(modem);
+	int i;
+
+	DBG("");
+
+	for (i = 0; i < NUM_DLC; i++)
+		g_at_chat_send(data->dlcs[i], "ATE0 +CMEE=1", NULL,
+						NULL, NULL, NULL);
+
+	g_at_chat_set_slave(data->dlcs[GPRS1_DLC], data->dlcs[NETREG_DLC]);
+	g_at_chat_set_slave(data->dlcs[GPRS2_DLC], data->dlcs[NETREG_DLC]);
+	g_at_chat_set_slave(data->dlcs[GPRS3_DLC], data->dlcs[NETREG_DLC]);
+
+	g_at_chat_send(data->dlcs[AUX_DLC], "AT+CFUN=4", NULL,
+					cfun_enable, modem, NULL);
+
+	data->dlc_init_source = 0;
+
+	return FALSE;
+}
+
 static gboolean dlc_ready_check(gpointer user_data)
 {
 	struct ofono_modem *modem = user_data;
@@ -360,18 +408,18 @@ static gboolean dlc_ready_check(gpointer user_data)
 	for (i = 0; i < NUM_DLC; i++) {
 		GIOChannel *channel = g_at_tty_open(dlc_nodes[i], NULL);
 
-		data->dlcs[i] = create_chat(channel, dlc_prefixes[i]);
-		if (!data->dlcs[i]) {
+		data->dlcs[i] = create_chat(channel, modem, dlc_prefixes[i]);
+		if (data->dlcs[i] == NULL) {
 			ofono_error("Failed to open %s", dlc_nodes[i]);
 			goto error;
 		}
 	}
 
-	g_at_chat_send(data->dlcs[AUX_DLC], "AT+CFUN=4", NULL,
-					cfun_enable, modem, NULL);
-
 	data->dlc_poll_source = 0;
 
+	/* iterate through mainloop */
+	data->dlc_init_source = g_timeout_add_seconds(0, dlc_setup, modem);
+
 	return FALSE;
 
 error:
@@ -386,19 +434,12 @@ error:
 static void setup_internal_mux(struct ofono_modem *modem)
 {
 	struct ifx_data *data = ofono_modem_get_data(modem);
-	GIOFlags flags;
 	int i;
 
 	DBG("");
 
-	flags = g_io_channel_get_flags(data->device) | G_IO_FLAG_NONBLOCK;
-	g_io_channel_set_flags(data->device, flags, NULL);
-
-	g_io_channel_set_encoding(data->device, NULL, NULL);
-	g_io_channel_set_buffered(data->device, FALSE);
-
 	data->mux = g_at_mux_new_gsm0710_basic(data->device, data->frame_size);
-	if (!data->mux)
+	if (data->mux == NULL)
 		goto error;
 
 	if (getenv("OFONO_MUX_DEBUG"))
@@ -409,15 +450,15 @@ static void setup_internal_mux(struct ofono_modem *modem)
 	for (i = 0; i < NUM_DLC; i++) {
 		GIOChannel *channel = g_at_mux_create_channel(data->mux);
 
-		data->dlcs[i] = create_chat(channel, dlc_prefixes[i]);
-		if (!data->dlcs[i]) {
+		data->dlcs[i] = create_chat(channel, modem, dlc_prefixes[i]);
+		if (data->dlcs[i] == NULL) {
 			ofono_error("Failed to create channel");
 			goto error;
 		}
         }
 
-	g_at_chat_send(data->dlcs[AUX_DLC], "AT+CFUN=4", NULL,
-					cfun_enable, modem, NULL);
+	/* wait for DLC creation to settle */
+	data->dlc_init_source = g_timeout_add(10, dlc_setup, modem);
 
 	return;
 
@@ -434,6 +475,11 @@ static void mux_setup_cb(gboolean ok, GAtResult *result, gpointer user_data)
 
 	DBG("");
 
+	if (data->mux_init_timeout > 0) {
+		g_source_remove(data->mux_init_timeout);
+		data->mux_init_timeout = 0;
+	}
+
 	g_at_chat_unref(data->dlcs[AUX_DLC]);
 	data->dlcs[AUX_DLC] = NULL;
 
@@ -473,6 +519,26 @@ error:
 	ofono_modem_set_powered(modem, FALSE);
 }
 
+static gboolean mux_timeout_cb(gpointer user_data)
+{
+	struct ofono_modem *modem = user_data;
+	struct ifx_data *data = ofono_modem_get_data(modem);
+
+	ofono_error("Timeout with multiplexer setup");
+
+	data->mux_init_timeout = 0;
+
+	g_at_chat_unref(data->dlcs[AUX_DLC]);
+	data->dlcs[AUX_DLC] = NULL;
+
+	g_io_channel_unref(data->device);
+	data->device = NULL;
+
+	ofono_modem_set_powered(modem, FALSE);
+
+	return FALSE;
+}
+
 static int ifx_enable(struct ofono_modem *modem)
 {
 	struct ifx_data *data = ofono_modem_get_data(modem);
@@ -508,14 +574,14 @@ static int ifx_enable(struct ofono_modem *modem)
 	}
 
 	data->device = g_at_tty_open(device, NULL);
-	if (!data->device)
+	if (data->device == NULL)
                 return -EIO;
 
 	syntax = g_at_syntax_new_gsmv1();
 	chat = g_at_chat_new(data->device, syntax);
 	g_at_syntax_unref(syntax);
 
-	if (!chat) {
+	if (chat == NULL) {
 		g_io_channel_unref(data->device);
                 return -EIO;
 	}
@@ -531,6 +597,9 @@ static int ifx_enable(struct ofono_modem *modem)
 	g_at_chat_send(chat, "AT+CMUX=0,0,,1509,10,3,30,,", NULL,
 					mux_setup_cb, modem, NULL);
 
+	data->mux_init_timeout = g_timeout_add_seconds(5, mux_timeout_cb,
+								modem);
+
 	data->dlcs[AUX_DLC] = chat;
 
 	return -EINPROGRESS;
@@ -592,7 +661,7 @@ static void ifx_set_online(struct ofono_modem *modem, ofono_bool_t online,
 
 	DBG("%p %s", modem, online ? "online" : "offline");
 
-	if (!cbd)
+	if (cbd == NULL)
 		goto error;
 
 	if (g_at_chat_send(data->dlcs[AUX_DLC], command, NULL,
@@ -617,6 +686,7 @@ static void ifx_pre_sim(struct ofono_modem *modem)
 	ofono_voicecall_create(modem, 0, "ifxmodem", data->dlcs[VOICE_DLC]);
 	ofono_audio_settings_create(modem, 0,
 					"ifxmodem", data->dlcs[VOICE_DLC]);
+	ofono_ctm_create(modem, 0, "ifxmodem", data->dlcs[AUX_DLC]);
 }
 
 static void ifx_post_sim(struct ofono_modem *modem)
@@ -626,7 +696,10 @@ static void ifx_post_sim(struct ofono_modem *modem)
 	DBG("%p", modem);
 
 	ofono_stk_create(modem, 0, "ifxmodem", data->dlcs[AUX_DLC]);
-	ofono_phonebook_create(modem, 0, "atmodem", data->dlcs[AUX_DLC]);
+	ofono_phonebook_create(modem, OFONO_VENDOR_IFX,
+					"atmodem", data->dlcs[AUX_DLC]);
+	ofono_call_forwarding_create(modem, 0, "atmodem", data->dlcs[AUX_DLC]);
+	ofono_radio_settings_create(modem, 0, "ifxmodem", data->dlcs[AUX_DLC]);
 }
 
 static void ifx_post_online(struct ofono_modem *modem)
@@ -638,7 +711,6 @@ static void ifx_post_online(struct ofono_modem *modem)
 
 	DBG("%p", modem);
 
-	ofono_radio_settings_create(modem, 0, "ifxmodem", data->dlcs[AUX_DLC]);
 	ofono_netreg_create(modem, OFONO_VENDOR_IFX,
 					"atmodem", data->dlcs[NETREG_DLC]);
 
@@ -648,7 +720,6 @@ static void ifx_post_online(struct ofono_modem *modem)
 	ofono_ussd_create(modem, 0, "atmodem", data->dlcs[AUX_DLC]);
 
 	ofono_ssn_create(modem, 0, "atmodem", data->dlcs[AUX_DLC]);
-	ofono_call_forwarding_create(modem, 0, "atmodem", data->dlcs[AUX_DLC]);
 	ofono_call_settings_create(modem, 0, "atmodem", data->dlcs[AUX_DLC]);
 	ofono_call_meter_create(modem, 0, "atmodem", data->dlcs[AUX_DLC]);
 	ofono_call_barring_create(modem, 0, "atmodem", data->dlcs[AUX_DLC]);
@@ -658,12 +729,27 @@ static void ifx_post_online(struct ofono_modem *modem)
 	if (mw)
 		ofono_message_waiting_register(mw);
 
-	gprs = ofono_gprs_create(modem, 0, "atmodem", data->dlcs[NETREG_DLC]);
-	gc = ofono_gprs_context_create(modem, 0,
-					"atmodem", data->dlcs[GPRS_DLC]);
+	gprs = ofono_gprs_create(modem, OFONO_VENDOR_IFX,
+					"atmodem", data->dlcs[NETREG_DLC]);
+	if (gprs == NULL)
+		return;
 
-	if (gprs && gc)
-		ofono_gprs_add_context(gprs, gc);
+	if (data->mux_ldisc < 0) {
+		gc = ofono_gprs_context_create(modem, 0,
+					"ifxmodem", data->dlcs[GPRS1_DLC]);
+		if (gc)
+			ofono_gprs_add_context(gprs, gc);
+
+		gc = ofono_gprs_context_create(modem, 0,
+					"ifxmodem", data->dlcs[GPRS2_DLC]);
+		if (gc)
+			ofono_gprs_add_context(gprs, gc);
+
+		gc = ofono_gprs_context_create(modem, 0,
+					"ifxmodem", data->dlcs[GPRS3_DLC]);
+		if (gc)
+			ofono_gprs_add_context(gprs, gc);
+	}
 }
 
 static struct ofono_modem_driver ifx_driver = {
