@@ -80,6 +80,10 @@ struct ofono_sms {
 	guint tx_source;
 	struct ofono_message_waiting *mw;
 	unsigned int mw_watch;
+	ofono_bool_t registered;
+	struct ofono_netreg *netreg;
+	unsigned int netreg_watch;
+	unsigned int status_watch;
 	struct ofono_sim *sim;
 	GKeyFile *settings;
 	char *imsi;
@@ -191,11 +195,11 @@ static unsigned int add_sms_handler(struct ofono_watchlist *watchlist,
 {
 	struct sms_handler *handler;
 
-	if (!notify)
+	if (notify == NULL)
 		return 0;
 
 	handler = g_try_new0(struct sms_handler, 1);
-	if (!handler)
+	if (handler == NULL)
 		return 0;
 
 	handler->dst = dst;
@@ -212,7 +216,7 @@ unsigned int __ofono_sms_text_watch_add(struct ofono_sms *sms,
 					ofono_sms_text_notify_cb_t cb,
 					void *data, ofono_destroy_func destroy)
 {
-	if (!sms)
+	if (sms == NULL)
 		return 0;
 
 	DBG("%p", sms);
@@ -223,7 +227,7 @@ unsigned int __ofono_sms_text_watch_add(struct ofono_sms *sms,
 gboolean __ofono_sms_text_watch_remove(struct ofono_sms *sms,
 					unsigned int id)
 {
-	if (!sms)
+	if (sms == NULL)
 		return FALSE;
 
 	DBG("%p", sms);
@@ -236,7 +240,7 @@ unsigned int __ofono_sms_datagram_watch_add(struct ofono_sms *sms,
 					int dst, int src, void *data,
 					ofono_destroy_func destroy)
 {
-	if (!sms)
+	if (sms == NULL)
 		return 0;
 
 	DBG("%p: dst %d, src %d", sms, dst, src);
@@ -248,7 +252,7 @@ unsigned int __ofono_sms_datagram_watch_add(struct ofono_sms *sms,
 gboolean __ofono_sms_datagram_watch_remove(struct ofono_sms *sms,
 					unsigned int id)
 {
-	if (!sms)
+	if (sms == NULL)
 		return FALSE;
 
 	DBG("%p", sms);
@@ -265,8 +269,7 @@ static DBusMessage *message_get_properties(DBusConnection *conn,
 	DBusMessageIter dict;
 
 	reply = dbus_message_new_method_return(msg);
-
-	if (!reply)
+	if (reply == NULL)
 		return NULL;
 
 	dbus_message_iter_init_append(reply, &iter);
@@ -330,7 +333,7 @@ static gboolean message_dbus_register(struct ofono_sms *sms, struct message *m)
 	DBusConnection *conn = ofono_dbus_get_connection();
 	const char *path;
 
-	if (!m)
+	if (m == NULL)
 		return FALSE;
 
 	path = __ofono_sms_message_path_from_uuid(sms, &m->uuid);
@@ -486,8 +489,7 @@ static DBusMessage *generate_get_properties_reply(struct ofono_sms *sms,
 	const char *bearer;
 
 	reply = dbus_message_new_method_return(msg);
-
-	if (!reply)
+	if (reply == NULL)
 		return NULL;
 
 	dbus_message_iter_init_append(reply, &iter);
@@ -541,7 +543,7 @@ static DBusMessage *sms_get_properties(DBusConnection *conn,
 	if (sms->pending)
 		return __ofono_error_busy(msg);
 
-	if (!sms->driver->sca_query)
+	if (sms->driver->sca_query == NULL)
 		return __ofono_error_not_implemented(msg);
 
 	if (sms->flags & MESSAGE_MANAGER_FLAG_CACHED)
@@ -749,6 +751,11 @@ static void tx_finished(const struct ofono_error *error, int mr, void *data)
 	DBG("tx_finished");
 
 	if (ok == FALSE) {
+		/* Retry again when back in online mode */
+		/* Note this does not increment retry count */
+		if (sms->registered == FALSE)
+			return;
+
 		if (!(entry->flags & OFONO_SMS_SUBMIT_FLAG_RETRY))
 			goto next_q;
 
@@ -812,6 +819,9 @@ next_q:
 
 	tx_queue_entry_destroy(entry);
 
+	if (sms->registered == FALSE)
+		return;
+
 	if (g_queue_peek_head(sms->txq)) {
 		DBG("Scheduling next");
 		sms->tx_source = g_timeout_add(0, tx_next, sms);
@@ -832,7 +842,10 @@ static gboolean tx_next(gpointer user_data)
 
 	sms->tx_source = 0;
 
-	if (!entry)
+	if (entry == NULL)
+		return FALSE;
+
+	if (sms->registered == FALSE)
 		return FALSE;
 
 	if (g_queue_get_length(sms->txq) > 1
@@ -845,6 +858,55 @@ static gboolean tx_next(gpointer user_data)
 	return FALSE;
 }
 
+static void netreg_status_watch(int status, int lac, int ci, int tech,
+					const char *mcc, const char *mnc,
+					void *data)
+{
+	struct ofono_sms *sms = data;
+
+	switch (status) {
+	case NETWORK_REGISTRATION_STATUS_REGISTERED:
+	case NETWORK_REGISTRATION_STATUS_ROAMING:
+		sms->registered = TRUE;
+		break;
+	default:
+		sms->registered = FALSE;
+		break;
+	}
+
+	if (sms->registered == FALSE)
+		return;
+
+	if (sms->tx_source > 0)
+		return;
+
+	if (g_queue_get_length(sms->txq))
+		sms->tx_source = g_timeout_add(0, tx_next, sms);
+}
+
+static void netreg_watch(struct ofono_atom *atom,
+				enum ofono_atom_watch_condition cond,
+				void *data)
+{
+	struct ofono_sms *sms = data;
+	int status;
+
+	if (cond == OFONO_ATOM_WATCH_CONDITION_UNREGISTERED) {
+		sms->registered = FALSE;
+		sms->status_watch = 0;
+		sms->netreg = NULL;
+		return;
+	}
+
+	sms->netreg = __ofono_atom_get_data(atom);
+	sms->status_watch = __ofono_netreg_add_status_watch(sms->netreg,
+					netreg_status_watch, sms, NULL);
+
+	status = ofono_netreg_get_status(sms->netreg);
+	netreg_status_watch(status, 0, 0, 0, NULL, NULL, sms);
+}
+
+
 /**
  * Generate a UUID from an SMS PDU List
  *
@@ -991,7 +1053,7 @@ static DBusMessage *sms_send_message(DBusConnection *conn, DBusMessage *msg,
 	msg_list = sms_text_prepare(to, text, sms->ref, use_16bit_ref,
 						sms->use_delivery_reports);
 
-	if (!msg_list)
+	if (msg_list == NULL)
 		return __ofono_error_invalid_format(msg);
 
 	flags = OFONO_SMS_SUBMIT_FLAG_RECORD_HISTORY;
@@ -1175,7 +1237,7 @@ static void dispatch_text_message(struct ofono_sms *sms,
 	struct sms_handler *h;
 	GSList *l;
 
-	if (!message)
+	if (message == NULL)
 		return;
 
 	if (cls == SMS_CLASS_0)
@@ -1186,7 +1248,7 @@ static void dispatch_text_message(struct ofono_sms *sms,
 	signal = dbus_message_new_signal(path, OFONO_MESSAGE_MANAGER_INTERFACE,
 						signal_name);
 
-	if (!signal)
+	if (signal == NULL)
 		return;
 
 	dbus_message_iter_init_append(signal, &iter);
@@ -1299,6 +1361,8 @@ static void sms_dispatch(struct ofono_sms *sms, GSList *sms_list)
 			}
 		}
 
+		DBG("dst %d src %d 8bit %u", cdst, csrc, is_8bit);
+
 		if (srcport != csrc || dstport != cdst) {
 			ofono_error("Source / Destination ports across "
 					"concatenated message are not the "
@@ -1324,8 +1388,7 @@ static void sms_dispatch(struct ofono_sms *sms, GSList *sms_list)
 		}
 
 		buf = sms_decode_datagram(sms_list, &len);
-
-		if (!buf)
+		if (buf == NULL)
 			return;
 
 		dispatch_app_datagram(sms, &uuid, dstport, srcport, buf, len,
@@ -1335,7 +1398,7 @@ static void sms_dispatch(struct ofono_sms *sms, GSList *sms_list)
 	} else {
 		char *message = sms_decode_text(sms_list);
 
-		if (!message)
+		if (message == NULL)
 			return;
 
 		dispatch_text_message(sms, &uuid, message, cls,
@@ -1357,7 +1420,7 @@ static void handle_deliver(struct ofono_sms *sms, const struct sms *incoming)
 	if (sms_extract_concatenation(incoming, &ref, &max, &seq)) {
 		GSList *sms_list;
 
-		if (!sms->assembly)
+		if (sms->assembly == NULL)
 			return;
 
 		sms_list = sms_assembly_add_fragment(sms->assembly,
@@ -1365,7 +1428,7 @@ static void handle_deliver(struct ofono_sms *sms, const struct sms *incoming)
 						&incoming->deliver.oaddr,
 						ref, max, seq);
 
-		if (!sms_list)
+		if (sms_list == NULL)
 			return;
 
 		sms_dispatch(sms, sms_list);
@@ -1489,7 +1552,7 @@ void ofono_sms_deliver_notify(struct ofono_sms *sms, unsigned char *pdu,
 
 		sim_atom = __ofono_modem_find_atom(modem, OFONO_ATOM_TYPE_SIM);
 
-		if (!sim_atom)
+		if (sim_atom == NULL)
 			return;
 
 		if (!__ofono_sim_service_available(
@@ -1500,7 +1563,7 @@ void ofono_sms_deliver_notify(struct ofono_sms *sms, unsigned char *pdu,
 
 		stk_atom = __ofono_modem_find_atom(modem, OFONO_ATOM_TYPE_STK);
 
-		if (!stk_atom)
+		if (stk_atom == NULL)
 			return;
 
 		__ofono_sms_sim_download(__ofono_atom_get_data(stk_atom),
@@ -1587,7 +1650,7 @@ void ofono_sms_status_notify(struct ofono_sms *sms, unsigned char *pdu,
 		return;
 	}
 
-	if (!sms_dcs_decode(s.deliver.dcs, &cls, NULL, NULL, NULL)) {
+	if (!sms_dcs_decode(s.status_report.dcs, &cls, NULL, NULL, NULL)) {
 		ofono_error("Unknown / Reserved DCS.  Ignoring");
 		return;
 	}
@@ -1631,6 +1694,19 @@ static void sms_unregister(struct ofono_atom *atom)
 		sms->mw = NULL;
 	}
 
+	if (sms->status_watch) {
+		__ofono_netreg_remove_status_watch(sms->netreg,
+							sms->status_watch);
+		sms->status_watch = 0;
+	}
+
+	if (sms->netreg_watch) {
+		__ofono_modem_remove_atom_watch(modem, sms->netreg_watch);
+		sms->netreg_watch = 0;
+	}
+
+	sms->netreg = NULL;
+
 	if (sms->messages) {
 		GHashTableIter iter;
 		struct message *m;
@@ -1814,7 +1890,7 @@ void ofono_sms_register(struct ofono_sms *sms)
 	DBusConnection *conn = ofono_dbus_get_connection();
 	struct ofono_modem *modem = __ofono_atom_get_modem(sms->atom);
 	const char *path = __ofono_atom_get_path(sms->atom);
-	struct ofono_atom *mw_atom;
+	struct ofono_atom *atom;
 	struct ofono_atom *sim_atom;
 
 	if (!g_dbus_register_interface(conn, path,
@@ -1833,11 +1909,19 @@ void ofono_sms_register(struct ofono_sms *sms)
 					OFONO_ATOM_TYPE_MESSAGE_WAITING,
 					mw_watch, sms, NULL);
 
-	mw_atom = __ofono_modem_find_atom(modem,
-					OFONO_ATOM_TYPE_MESSAGE_WAITING);
+	atom = __ofono_modem_find_atom(modem, OFONO_ATOM_TYPE_MESSAGE_WAITING);
 
-	if (mw_atom && __ofono_atom_get_registered(mw_atom))
-		mw_watch(mw_atom, OFONO_ATOM_WATCH_CONDITION_REGISTERED, sms);
+	if (atom && __ofono_atom_get_registered(atom))
+		mw_watch(atom, OFONO_ATOM_WATCH_CONDITION_REGISTERED, sms);
+
+	sms->netreg_watch = __ofono_modem_add_atom_watch(modem,
+					OFONO_ATOM_TYPE_NETREG,
+					netreg_watch, sms, NULL);
+
+	atom = __ofono_modem_find_atom(modem, OFONO_ATOM_TYPE_NETREG);
+
+	if (atom && __ofono_atom_get_registered(atom))
+		netreg_watch(atom, OFONO_ATOM_WATCH_CONDITION_REGISTERED, sms);
 
 	sim_atom = __ofono_modem_find_atom(modem, OFONO_ATOM_TYPE_SIM);
 
@@ -1925,7 +2009,7 @@ int __ofono_sms_txq_submit(struct ofono_sms *sms, GSList *list,
 
 	g_queue_push_tail(sms->txq, entry);
 
-	if (g_queue_get_length(sms->txq) == 1)
+	if (sms->registered && g_queue_get_length(sms->txq) == 1)
 		sms->tx_source = g_timeout_add(0, tx_next, sms);
 
 	if (uuid)
