@@ -41,6 +41,7 @@
 enum allowed_error {
 	ALLOWED_ERROR_GO_BACK	= 0x1,
 	ALLOWED_ERROR_TERMINATE	= 0x2,
+	ALLOWED_ERROR_BUSY		= 0x4,
 };
 
 struct stk_agent {
@@ -62,6 +63,7 @@ struct stk_agent {
 #define ERROR_PREFIX OFONO_SERVICE ".Error"
 #define GOBACK_ERROR ERROR_PREFIX ".GoBack"
 #define TERMINATE_ERROR ERROR_PREFIX ".EndSession"
+#define BUSY_ERROR ERROR_PREFIX ".Busy"
 
 static void stk_agent_send_noreply(struct stk_agent *agent, const char *method)
 {
@@ -194,6 +196,12 @@ static int check_error(struct stk_agent *agent, DBusMessage *reply,
 		goto out;
 	}
 
+	if ((allowed_errors & ALLOWED_ERROR_BUSY) &&
+			g_str_equal(err.name, BUSY_ERROR)) {
+		*out_result = STK_AGENT_RESULT_BUSY;
+		goto out;
+	}
+
 	result = -EINVAL;
 
 out:
@@ -218,7 +226,7 @@ struct stk_agent *stk_agent_new(const char *path, const char *sender,
 	struct stk_agent *agent = g_try_new0(struct stk_agent, 1);
 	DBusConnection *conn = ofono_dbus_get_connection();
 
-	if (!agent)
+	if (agent == NULL)
 		return NULL;
 
 	agent->path = g_strdup(path);
@@ -376,8 +384,8 @@ static void display_text_cb(DBusPendingCall *call, void *data)
 	gboolean remove_agent;
 
 	if (check_error(agent, reply,
-			ALLOWED_ERROR_GO_BACK | ALLOWED_ERROR_TERMINATE,
-			&result) == -EINVAL) {
+			ALLOWED_ERROR_GO_BACK | ALLOWED_ERROR_TERMINATE |
+			ALLOWED_ERROR_BUSY, &result) == -EINVAL) {
 		remove_agent = TRUE;
 		goto error;
 	}
@@ -956,3 +964,52 @@ int stk_agent_loop_tone(struct stk_agent *agent, const char *text,
 
 	return 0;
 }
+
+static void action_info_cb(DBusPendingCall *call, void *data)
+{
+	struct stk_agent *agent = data;
+	DBusMessage *reply = dbus_pending_call_steal_reply(call);
+	enum stk_agent_result result;
+	gboolean remove_agent;
+
+	if (check_error(agent, reply, 0, &result) == -EINVAL) {
+		remove_agent = TRUE;
+		goto error;
+	}
+
+	if (dbus_message_get_args(reply, NULL, DBUS_TYPE_INVALID) == FALSE) {
+		ofono_error("Can't parse the reply to DisplayActionInfo()");
+		remove_agent = TRUE;
+		goto error;
+	}
+
+	goto done;
+
+	CALLBACK_END();
+}
+
+int stk_agent_display_action_info(struct stk_agent *agent, const char *text,
+					const struct stk_icon_id *icon)
+{
+	DBusConnection *conn = ofono_dbus_get_connection();
+
+	agent->msg = dbus_message_new_method_call(agent->bus, agent->path,
+						OFONO_SIM_APP_INTERFACE,
+						"DisplayActionInformation");
+	if (agent->msg == NULL)
+		return -ENOMEM;
+
+	dbus_message_append_args(agent->msg,
+					DBUS_TYPE_STRING, &text,
+					DBUS_TYPE_BYTE, &icon->id,
+					DBUS_TYPE_INVALID);
+
+	if (dbus_connection_send_with_reply(conn, agent->msg, &agent->call,
+						0) == FALSE ||
+			agent->call == NULL)
+		return -EIO;
+
+	dbus_pending_call_set_notify(agent->call, action_info_cb, agent, NULL);
+
+	return 0;
+}
